@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005-2010 Steven L. Scott
 
@@ -18,16 +19,16 @@
 #ifndef BOOM_BINOMIAL_LOGIT_SPIKE_SLAB_SAMPLER_HPP_
 #define BOOM_BINOMIAL_LOGIT_SPIKE_SLAB_SAMPLER_HPP_
 
-#include <Models/Glm/PosteriorSamplers/BinomialLogitAuxmixSampler.hpp>
-#include <Models/Glm/VariableSelectionPrior.hpp>
-#include <LinAlg/Selector.hpp>
+#include "LinAlg/Selector.hpp"
+#include "Models/Glm/PosteriorSamplers/BinomialLogitAuxmixSampler.hpp"
+#include "Models/Glm/VariableSelectionPrior.hpp"
 
-namespace BOOM{
-  class BinomialLogitSpikeSlabSampler : public BinomialLogitAuxmixSampler{
+namespace BOOM {
+  class BinomialLogitSpikeSlabSampler : public BinomialLogitAuxmixSampler {
    public:
-    BinomialLogitSpikeSlabSampler(BinomialLogitModel *m,
-                                  Ptr<MvnBase> pri,
-                                  Ptr<VariableSelectionPrior> vpri,
+    BinomialLogitSpikeSlabSampler(BinomialLogitModel *model,
+                                  const Ptr<MvnBase> &pri,
+                                  const Ptr<VariableSelectionPrior> &vpri,
                                   int clt_threshold,
                                   RNG &seeding_rng = GlobalRng::rng);
 
@@ -36,12 +37,12 @@ namespace BOOM{
 
     void draw_model_indicators();
     virtual void draw_beta();
-    double log_model_prob(const Selector &gamma)const;
+    double log_model_prob(const Selector &gamma) const;
 
     // toggles whether or not draw_model_indicators is called as part
     // of draw().  If you don't want model selection to be part of the
     // MCMC then you need to manually manage the include/exclude
-    // decisions through m_->coef(), preferably before the model is
+    // decisions through model_->coef(), preferably before the model is
     // passed to the constructor
     void allow_model_selection(bool tf);
 
@@ -56,28 +57,36 @@ namespace BOOM{
     // log posterior (the objective function) in posterior_mode_value_;.
     void find_posterior_mode(double epsilon = 1e-5) override;
 
-    bool can_find_posterior_mode() const override {
-      return true;
+    bool can_find_posterior_mode() const override { return true; }
+
+    bool posterior_mode_found() const { return posterior_mode_found_; }
+
+    double log_posterior_at_mode() const { return log_posterior_at_mode_; }
+
+    void set_spike(const Ptr<VariableSelectionPrior> &new_spike) {
+      spike_ = check_spike_dimension(new_spike);
     }
 
-    bool posterior_mode_found() const {
-      return posterior_mode_found_;
-    }
-
-    double log_posterior_at_mode() const {
-      return log_posterior_at_mode_;
+    void set_slab(const Ptr<MvnBase> &new_slab) {
+      slab_ = check_slab_dimension(new_slab);
     }
 
    private:
     double mcmc_one_flip(Selector &mod, uint which_var, double logp_old);
-    BinomialLogitModel *m_;
-    Ptr<MvnBase> pri_;
-    Ptr<VariableSelectionPrior> vpri_;
+    BinomialLogitModel *model_;
+    Ptr<MvnBase> slab_;
+    Ptr<VariableSelectionPrior> spike_;
     bool allow_model_selection_;
     int max_flips_;
     bool posterior_mode_found_;
     double log_posterior_at_mode_;
+
+    // If the argument's dimension matches m_->xdim() the argument is returned.
+    // Otherwise an error is reported.
+    const Ptr<VariableSelectionPrior> &check_spike_dimension(
+        const Ptr<VariableSelectionPrior> &spike);
+    const Ptr<MvnBase> &check_slab_dimension(const Ptr<MvnBase> &slab);
   };
 
 }  // namespace BOOM
-#endif // BOOM_BINOMIAL_LOGIT_SPIKE_SLAB_SAMPLER_HPP_
+#endif  // BOOM_BINOMIAL_LOGIT_SPIKE_SLAB_SAMPLER_HPP_
