@@ -1,20 +1,18 @@
 #include "nmath.hpp"
-#include <stdexcept>
 #include <sstream>
 #include "cpputil/report_error.hpp"
-using namespace std;
 
 namespace Rmath{
-  void mathlib_error(const string &s){
+  void mathlib_error(const std::string &s){
     report_error(s); }
 
-  void mathlib_error(const string &s, int d){
-    ostringstream err;
+  void mathlib_error(const std::string &s, int d){
+    std::ostringstream err;
     err << s << " " << d << std::endl;
     report_error(err.str());
   }
-  void mathlib_error(const string &s, double d){
-    ostringstream err;
+  void mathlib_error(const std::string &s, double d){
+    std::ostringstream err;
     err << s << " " << d << std::endl;
     report_error(err.str());
   }
