@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005-2015 Steven L. Scott
 
@@ -15,26 +16,25 @@
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
-#include <Models/Glm/ZeroInflatedLognormalRegression.hpp>
-#include <distributions.hpp>
-#include <cpputil/math_utils.hpp>
-#include <cpputil/report_error.hpp>
+#include "Models/Glm/ZeroInflatedLognormalRegression.hpp"
+#include "cpputil/math_utils.hpp"
+#include "cpputil/report_error.hpp"
+#include "distributions.hpp"
 
 namespace BOOM {
 
-namespace {
-  typedef ZeroInflatedLognormalRegressionModel ZILRM;
-}  // namespace
+  namespace {
+    typedef ZeroInflatedLognormalRegressionModel ZILRM;
+  }  // namespace
 
-  ZILRM::ZeroInflatedLognormalRegressionModel(
-      int dimension, double zero_threshold)
-      : ParamPolicy(new GlmCoefs(dimension),
-                    new UnivParams(1.0),
+  ZILRM::ZeroInflatedLognormalRegressionModel(int dimension,
+                                              double zero_threshold)
+      : ParamPolicy(new GlmCoefs(dimension), new UnivParams(1.0),
                     new GlmCoefs(dimension)),
-        zero_threshold_(zero_threshold)
-  {}
+        DataPolicy(new NeRegSuf(dimension)),
+        zero_threshold_(zero_threshold) {}
 
-  ZILRM * ZILRM::clone() const { return new ZILRM(*this);}
+  ZILRM *ZILRM::clone() const { return new ZILRM(*this); }
 
   double ZILRM::expected_value(const Vector &x) const {
     double mu = regression_coefficients().predict(x);
@@ -55,10 +55,10 @@ namespace {
   //           + p(x)*(1-p(x))*lognormal_mean^2
   double ZILRM::variance(const Vector &x) const {
     double mu = regression_coefficients().predict(x);
-    double lognormal_variance = (exp(sigsq()) - 1) * exp(2 * mu + sigsq());
+    double lognormal_variance = expm1(sigsq()) * exp(2 * mu + sigsq());
     double lognormal_mean = exp(mu + 0.5 * sigsq());
     double p = probability_zero(x);
-    return (1-p) * lognormal_variance + p * (1-p) * square(lognormal_mean);
+    return (1 - p) * lognormal_variance + p * (1 - p) * square(lognormal_mean);
   }
 
   double ZILRM::standard_deviation(const Vector &x) const {
@@ -74,25 +74,24 @@ namespace {
     return 1.0 - probability_nonzero(x);
   }
 
-  Ptr<GlmCoefs> ZILRM::regression_coefficient_ptr() {
-    return prm1();
+  void ZILRM::add_data(const Ptr<Data> &dp) { add_data(DAT(dp)); }
+
+  void ZILRM::add_data(const Ptr<RegressionData> &dp) {
+    if (dp->y() > zero_threshold_) {
+      suf()->add_mixture_data(log(dp->y()), dp->x(), 1.0);
+    }
+    IID_DataPolicy<RegressionData>::add_data(dp);
   }
 
-  const GlmCoefs & ZILRM::regression_coefficients() const {
-    return prm1_ref();
-  }
+  Ptr<GlmCoefs> ZILRM::regression_coefficient_ptr() { return prm1(); }
 
-  Ptr<UnivParams> ZILRM::sigsq_prm() {
-    return prm2();
-  }
+  const GlmCoefs &ZILRM::regression_coefficients() const { return prm1_ref(); }
 
-  double ZILRM::sigsq() const {
-    return prm2_ref().value();
-  }
+  Ptr<UnivParams> ZILRM::sigsq_prm() { return prm2(); }
 
-  double ZILRM::sigma() const {
-    return sqrt(sigsq());
-  }
+  double ZILRM::sigsq() const { return prm2_ref().value(); }
+
+  double ZILRM::sigma() const { return sqrt(sigsq()); }
 
   void ZILRM::set_sigsq(double sigsq) {
     if (sigsq <= 0) {
@@ -101,12 +100,28 @@ namespace {
     prm2_ref().set(sigsq);
   }
 
-  Ptr<GlmCoefs> ZILRM::logit_coefficient_ptr() {
-    return prm3();
-  }
+  Ptr<GlmCoefs> ZILRM::logit_coefficient_ptr() { return prm3(); }
 
-  const GlmCoefs & ZILRM::logit_coefficients() const {
-    return prm3_ref();
+  const GlmCoefs &ZILRM::logit_coefficients() const { return prm3_ref(); }
+
+  double ZILRM::log_likelihood(const Vector &logit_coefficients,
+                               const Vector &regression_coefficients,
+                               double sigsq) const {
+    double loglike =
+        RegressionModel::log_likelihood(regression_coefficients, sigsq, *suf());
+    const std::vector<Ptr<RegressionData>> &data(dat());
+    for (int i = 0; i < data.size(); ++i) {
+      bool success = data[i]->y() > zero_threshold_;
+      double log_odds = logit_coefficients.dot(data[i]->x());
+      // log [(p/q)^y * q] = y * eta + log(q)
+      loglike += success * log_odds +
+                 plogis(log_odds,
+                        0,      // location
+                        1,      // scale
+                        false,  // lower tail, because we want log q not log p.
+                        true);  // logscale
+    }
+    return loglike;
   }
 
   double ZILRM::sim(const Vector &x, RNG &rng) const {
