@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005-2010 Steven L. Scott
 
@@ -16,30 +17,25 @@
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
 
-#include <Models/PosteriorSamplers/ZeroMeanMvnConjSampler.hpp>
-#include <Models/ZeroMeanMvnModel.hpp>
-#include <Models/MvnBase.hpp>
-#include <distributions.hpp>
+#include "Models/PosteriorSamplers/ZeroMeanMvnConjSampler.hpp"
+#include "Models/MvnBase.hpp"
+#include "Models/ZeroMeanMvnModel.hpp"
+#include "distributions.hpp"
 
-namespace BOOM{
+namespace BOOM {
   typedef ZeroMeanMvnConjSampler ZMMCS;
   ZMMCS::ZeroMeanMvnConjSampler(ZeroMeanMvnModel *m,
-                                Ptr<WishartModel> siginv_prior,
+                                const Ptr<WishartModel> &siginv_prior,
                                 RNG &seeding_rng)
-      :PosteriorSampler(seeding_rng),
-       m_(m),
-       siginv_prior_(siginv_prior)
-  {}
-  ZMMCS::ZeroMeanMvnConjSampler(ZeroMeanMvnModel *m,
-                                double prior_df,
-                                double sigma_guess,
-                                RNG &seeding_rng)
-      :PosteriorSampler(seeding_rng),
-       m_(m),
-       siginv_prior_(new WishartModel(m->dim(), prior_df, pow(sigma_guess, 2)))
-  {}
+      : PosteriorSampler(seeding_rng), m_(m), siginv_prior_(siginv_prior) {}
+  ZMMCS::ZeroMeanMvnConjSampler(ZeroMeanMvnModel *m, double prior_df,
+                                double sigma_guess, RNG &seeding_rng)
+      : PosteriorSampler(seeding_rng),
+        m_(m),
+        siginv_prior_(
+            new WishartModel(m->dim(), prior_df, pow(sigma_guess, 2))) {}
 
-  void ZMMCS::draw(){
+  void ZMMCS::draw() {
     Ptr<MvnSuf> s = m_->suf();
     double df = s->n() + siginv_prior_->nu();
     SpdMatrix S = s->center_sumsq(m_->mu()) + siginv_prior_->sumsq();
@@ -47,22 +43,21 @@ namespace BOOM{
     m_->prm()->set_ivar(S);
   }
 
-  double ZMMCS::logpri()const{
-    return siginv_prior_->logp(m_->siginv());
-  }
+  double ZMMCS::logpri() const { return siginv_prior_->logp(m_->siginv()); }
 
   // posterior mode with respect to Sigma inverse.
-  void ZMMCS::find_posterior_mode(double){
+  void ZMMCS::find_posterior_mode(double) {
     Ptr<MvnSuf> s = m_->suf();
     SpdMatrix Sumsq = s->center_sumsq(m_->mu()) + siginv_prior_->sumsq();
     double nu = s->n() + siginv_prior_->nu();
 
     nu = nu - m_->dim() - 1;
-    if(nu < 0) {
-      report_error("degrees of freedom too small in "
-                   "ZeroMeanMvnConjSampler::find_posterior_mode");
+    if (nu < 0) {
+      report_error(
+          "degrees of freedom too small in "
+          "ZeroMeanMvnConjSampler::find_posterior_mode");
     }
     m_->prm()->set_var(Sumsq / nu);
   }
 
-}
+}  // namespace BOOM
